package com.muyu.product.domain;

import com.muyu.common.core.annotation.Excel;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.product.domain.req.BrandReq;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

import java.util.Date;

/**
 * 品牌对象 brand
 *
 * @author Saisai
 * @date 2024-02-29
 */

@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
public class Brand extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 品牌名称
     */
    @Excel(name = "品牌名称")
    private String name;

    /**
     * 图像标识
     */
    @Excel(name = "图像标识")
    private String logo;

    /**
     * 描述
     */
    @Excel(name = "描述")
    private String introduction;

    /**
     * 品牌启用
     */
    @Excel(name = "品牌启用")
    private String status;

    /**
     * 公司地址
     */
    @Excel(name = "公司地址")
    private String addressName;


    //添加数据构造体
    public static Brand saveBuilder(BrandReq brandReq) {
        return Brand.builder()
                .name(brandReq.getName())
                .logo(brandReq.getLogo())
                .introduction(brandReq.getIntroduction())
                .status(brandReq.getStatus())
                .createBy(SecurityUtils.getUsername())
                .createTime(new Date())
                .build();
    }


    //修改构建体
    public static Brand updateBuilder(BrandReq brandReq) {
        return Brand.builder()
                .id(brandReq.getId())
                .name(brandReq.getName())
                .logo(brandReq.getLogo())
                .introduction(brandReq.getIntroduction())
                .status(brandReq.getStatus())
                .updateBy(SecurityUtils.getUsername())
                .updateTime(new Date())
                .build();
    }

}
