package com.muyu.product.domain;

import com.muyu.common.core.annotation.Excel;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.product.domain.model.CategoryInfoSaveModel;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.util.Date;
import java.util.List;
import java.util.function.Supplier;

/**
 * 品牌品类中间对象 brand_category
 *
 * @author Saisai
 * @date 2024-02-29
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
public class BrandCategory extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long id;

    /** 品类编号 */
    @Excel(name = "品类编号")
    private Long categoryId;

    /** 品牌编号 */
    @Excel(name = "品牌编号")
    private Long brandId;


    public static List<BrandCategory> saveBuilderList(CategoryInfoSaveModel categoryReq, Supplier<String> getUsername) {
        return categoryReq.getCheckedBrandIds().stream().map(
                brandId -> BrandCategory.saveBuilder(categoryReq.getId(),brandId,getUsername)
        ).toList();
    }

    private static BrandCategory saveBuilder(Long categoryId, Long brandId, Supplier<String> getUsername) {
        return BrandCategory.builder()
                .brandId(brandId)
                .categoryId(categoryId)
                .createBy(getUsername.get())
                .createTime(new Date())
                .build();
    }
}
