package com.muyu.product.domain;

import com.muyu.common.core.annotation.Excel;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.product.domain.model.CategoryInfoSaveModel;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.util.Date;
import java.util.List;
import java.util.function.Supplier;

/**
 * 品类属性中间对象 category_attribute
 *
 * @author Saisai
 * @date 2024-02-29
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
public class CategoryAttribute extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long id;

    /** 属性编号 */
    @Excel(name = "属性编号")
    private Long attributeId;

    /** 品类编号 */
    @Excel(name = "品类编号")
    private Long categoryId;

    public static CategoryAttribute categoryBuilder(Long categoryId, Long attributeId, Supplier<String> username) {
        return CategoryAttribute.builder()
                .categoryId(categoryId)
                .attributeId(attributeId)
                .createBy(username.get())
                .createTime(new Date())
                .build();
    }

    public static List<CategoryAttribute> saveBuilder(CategoryInfoSaveModel categoryReq, Supplier<String> username) {
        return categoryReq.getCheckedAttributeIds().stream().map(
                attributeId -> categoryBuilder(categoryReq.getId(),attributeId,username)
        ).toList();
    }
}
