package com.muyu.product.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.product.domain.BrandCategory;
import com.muyu.product.service.IBrandCategoryService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 品牌品类中间Controller
 *
 * @author Saisai
 * @date 2024-02-29
 */
@RestController
@RequestMapping("/category_brand")
public class BrandCategoryController extends BaseController
{
    @Autowired
    private IBrandCategoryService brandCategoryService;

    /**
     * 查询品牌品类中间列表
     */
    @RequiresPermissions("product:category_brand:list")
    @GetMapping("/list")
    public Result<TableDataInfo<BrandCategory>> list(BrandCategory brandCategory)
    {
        startPage();
        List<BrandCategory> list = brandCategoryService.selectBrandCategoryList(brandCategory);
        return getDataTable(list);
    }

    /**
     * 导出品牌品类中间列表
     */
    @RequiresPermissions("product:category_brand:export")
    @Log(title = "品牌品类中间", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BrandCategory brandCategory)
    {
        List<BrandCategory> list = brandCategoryService.selectBrandCategoryList(brandCategory);
        ExcelUtil<BrandCategory> util = new ExcelUtil<BrandCategory>(BrandCategory.class);
        util.exportExcel(response, list, "品牌品类中间数据");
    }

    /**
     * 获取品牌品类中间详细信息
     */
    @RequiresPermissions("product:category_brand:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(brandCategoryService.selectBrandCategoryById(id));
    }

    /**
     * 新增品牌品类中间
     */
    @RequiresPermissions("product:category_brand:add")
    @Log(title = "品牌品类中间", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody BrandCategory brandCategory)
    {
        return toAjax(brandCategoryService.insertBrandCategory(brandCategory));
    }

    /**
     * 修改品牌品类中间
     */
    @RequiresPermissions("product:category_brand:edit")
    @Log(title = "品牌品类中间", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody BrandCategory brandCategory)
    {
        return toAjax(brandCategoryService.updateBrandCategory(brandCategory));
    }

    /**
     * 删除品牌品类中间
     */
    @RequiresPermissions("product:category_brand:remove")
    @Log(title = "品牌品类中间", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(brandCategoryService.deleteBrandCategoryByIds(ids));
    }
}
