package com.muyu.product.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.product.domain.model.CategoryInfoSaveModel;
import com.muyu.product.domain.req.CategoryReq;
import com.muyu.product.domain.resp.CategoryResp;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.product.domain.CategoryInfo;
import com.muyu.product.service.ICategoryInfoService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;

/**
 * 品类信息Controller
 *
 * @author Saisai
 * @date 2024-02-29
 */
@RestController
@RequestMapping("/category_info")
public class CategoryInfoController extends BaseController
{
    @Autowired
    private ICategoryInfoService categoryInfoService;

    /**
     * 查询品类信息列表
     */
    @RequiresPermissions("product:category_info:list")
    @GetMapping("/list")
    public Result list(CategoryInfoSaveModel categoryInfoSaveModel)
    {
        List<CategoryResp> list = categoryInfoService.selectCategoryInfoList(categoryInfoSaveModel);
        return success(list);
    }

    /**
     * 导出品类信息列表
     */
    @RequiresPermissions("product:category_info:export")
    @Log(title = "品类信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CategoryInfoSaveModel categoryInfoSaveModel)
    {
        List<CategoryResp> list = categoryInfoService.selectCategoryInfoList(categoryInfoSaveModel);
        ExcelUtil<CategoryResp> util = new ExcelUtil<CategoryResp>(CategoryResp.class);
        util.exportExcel(response, list, "品类信息数据");
    }

    /**
     * 获取品类信息详细信息
     */
    @RequiresPermissions("product:category_info:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(categoryInfoService.selectCategoryInfoById(id));
    }

    /**
     * 新增品类信息
     */
    @RequiresPermissions("product:category_info:add")
    @Log(title = "品类信息", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody CategoryReq categoryReq)
    {
        return toAjax(categoryInfoService.save(CategoryInfoSaveModel.saveBuilder(categoryReq, SecurityUtils::getUsername  )));
    }

    /**
     * 修改品类信息
     */
    @RequiresPermissions("product:category_info:edit")
    @Log(title = "品类信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody CategoryInfoSaveModel categoryInfoSaveModel)
    {
        return toAjax(categoryInfoService.updateCategoryInfo(categoryInfoSaveModel));
    }

    /**
     * 删除品类信息
     */
    @RequiresPermissions("product:category_info:remove")
    @Log(title = "品类信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(categoryInfoService.deleteCategoryInfoByIds(ids));
    }
}
