package com.muyu.product.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.product.domain.RuleProduct;
import com.muyu.product.service.IRuleProductService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 规格商品中间Controller
 *
 * @author saisai
 * @date 2024-02-29
 */
@RestController
@RequestMapping("/rule_product")
public class RuleProductController extends BaseController
{
    @Autowired
    private IRuleProductService ruleProductService;

    /**
     * 查询规格商品中间列表
     */
    @RequiresPermissions("product:product:list")
    @GetMapping("/list")
    public Result<TableDataInfo<RuleProduct>> list(RuleProduct ruleProduct)
    {
        startPage();
        List<RuleProduct> list = ruleProductService.selectRuleProductList(ruleProduct);
        return getDataTable(list);
    }

    /**
     * 导出规格商品中间列表
     */
    @RequiresPermissions("product:product:export")
    @Log(title = "规格商品中间", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RuleProduct ruleProduct)
    {
        List<RuleProduct> list = ruleProductService.selectRuleProductList(ruleProduct);
        ExcelUtil<RuleProduct> util = new ExcelUtil<RuleProduct>(RuleProduct.class);
        util.exportExcel(response, list, "规格商品中间数据");
    }

    /**
     * 获取规格商品中间详细信息
     */
    @RequiresPermissions("product:product:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(ruleProductService.selectRuleProductById(id));
    }

    /**
     * 新增规格商品中间
     */
    @RequiresPermissions("product:product:add")
    @Log(title = "规格商品中间", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody RuleProduct ruleProduct)
    {
        return toAjax(ruleProductService.insertRuleProduct(ruleProduct));
    }

    /**
     * 修改规格商品中间
     */
    @RequiresPermissions("product:product:edit")
    @Log(title = "规格商品中间", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody RuleProduct ruleProduct)
    {
        return toAjax(ruleProductService.updateRuleProduct(ruleProduct));
    }

    /**
     * 删除规格商品中间
     */
    @RequiresPermissions("product:product:remove")
    @Log(title = "规格商品中间", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(ruleProductService.deleteRuleProductByIds(ids));
    }
}
