package com.muyu.product.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.product.domain.AsAttributeGroup;
import com.muyu.product.domain.Attribute;
import com.muyu.product.domain.AttributeGroup;
import com.muyu.product.domain.req.AttributeGroupReq;
import com.muyu.product.domain.resp.AttributeGroupResp;
import com.muyu.product.mapper.AsAttributeGroupMapper;
import com.muyu.product.mapper.AttributeGroupMapper;
import com.muyu.product.service.IAsAttributeGroupService;
import com.muyu.product.service.IAttributeGroupService;
import com.muyu.product.service.IAttributeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * 属性组Service业务层处理
 *
 * @author muyu
 * @date 2024-02-29
 */
@Service
public class AttributeGroupServiceImpl extends ServiceImpl<AttributeGroupMapper, AttributeGroup>
        implements IAttributeGroupService {
    @Autowired
    private AttributeGroupMapper attributeGroupMapper;

    @Autowired
    private IAsAttributeGroupService asAttributeGroupService;

    @Autowired
    private IAttributeService attributeService;

    /**
     * 查询属性组
     *
     * @param id 属性组主键
     * @return 属性组
     */
    @Override
    public AttributeGroup selectAttributeGroupById(Long id) {
        AttributeGroup group = attributeGroupMapper.selectAttributeGroupById(id);
        setAttributeList(group);
        return group;
    }

    /**
     * 将查出来的组内属性赋值给返回值对象
     * @param group
     */
    private void setAttributeList(AttributeGroup group) {
        List<Attribute> attributeLongs = new ArrayList<>();
        List<Long> longs = new ArrayList<>();
        List<Long> asIds = new ArrayList<>();
        List<AsAttributeGroup> asAttributeGroups = asAttributeGroupService.selectAsAttributeGroupList(AsAttributeGroup.builder()
                .groupId(group.getId())
                .build());
        asAttributeGroups.forEach(asAttributeGroup -> attributeLongs.add(attributeService.selectAttributeById(asAttributeGroup.getAttributeId())));
        asAttributeGroups.forEach(asAttributeGroup -> longs.add(attributeService.selectAttributeById(asAttributeGroup.getAttributeId()).getId()));
        asAttributeGroups.forEach(asAttributeGroup -> asIds.add(asAttributeGroup.getId()));
//        group.setAttributeList(attributeLongs);
//        group.setCheckedAttributeIds(longs);
//        group.setAsAttributeIds(asIds);


    }

    /**
     * 查询属性组列表
     *
     * @param attributeGroup 属性组
     * @return 属性组
     */
    @Override
    public List<AttributeGroupResp> selectAttributeGroupList(AttributeGroup attributeGroup) {
        List<AttributeGroup> attributeGroups = attributeGroupMapper.selectAttributeGroupList(attributeGroup);
        attributeGroups.forEach(this::setAttributeList);
        List<AttributeGroupResp> list = attributeGroups.stream().map(group ->
                AttributeGroupResp.saveBuilder(group,attributeService.listByIds(asAttributeGroupService.list(
                                new LambdaQueryWrapper<AsAttributeGroup>()
                                        .eq(AsAttributeGroup::getGroupId, group.getId()))
                        .stream().map(AsAttributeGroup::getAttributeId).toList()))
        ).toList();
        return list;
    }

    /**
     * 新增属性组
     *
     * @param attributeGroupReq 属性组
     * @return 结果
     */
    @Override
    public int insertAttributeGroup(AttributeGroupReq attributeGroupReq) {
        AttributeGroup group = AttributeGroup.createBuilder(attributeGroupReq);
        int i = attributeGroupMapper.insertAttributeGroup(group);
        List<AsAttributeGroup> asAttributeGroups =
                attributeGroupReq.getCheckedAttributeIds()
                        .stream().map(attributeId ->
                                AsAttributeGroup
                                        .saveBuilder(group.getId(), attributeId))
                        .toList();
        asAttributeGroupService.saveBatch(asAttributeGroups);
//        asAttributeGroups.forEach(asAttributeGroup -> asAttributeGroupMapper.insertAsAttributeGroup(asAttributeGroup));
        return asAttributeGroups.size();
    }

    /**
     * 修改属性组
     *
     * @param attributeGroupReq 属性组
     * @return 结果
     */
    @Override
    public int updateAttributeGroup(AttributeGroupReq attributeGroupReq) {
        AttributeGroup attributeGroup = AttributeGroupReq.updateBuilder(attributeGroupReq);
        this.setAttributeList(attributeGroup);
        int i = attributeGroupMapper.updateAttributeGroup(attributeGroup);
        List<AsAttributeGroup> asAttributeGroups =
                attributeGroupReq.getCheckedAttributeIds().stream()
                        .map(attributeId -> AsAttributeGroup
                                .saveBuilder(attributeGroup.getId(), attributeId))
                        .toList();
//        attributeGroup.getAsAttributeIds()
        asAttributeGroupService.removeBatchByIds(asAttributeGroupService.list(new LambdaQueryWrapper<AsAttributeGroup>()
                .eq(AsAttributeGroup::getGroupId,attributeGroup.getId()))
                .stream().map(AsAttributeGroup::getId).toList()
        );
        asAttributeGroupService.saveBatch(asAttributeGroups);
//        asAttributeGroups.forEach(asAttributeGroup -> asAttributeGroupService.updateAsAttributeGroup(asAttributeGroup));
        return asAttributeGroups.size();
    }

    /**
     * 批量删除属性组
     *
     * @param ids 需要删除的属性组主键
     * @return 结果
     */
    @Override
    @Transactional
    public int deleteAttributeGroupByIds(Long[] ids) {
        LambdaQueryWrapper<AsAttributeGroup> queryWrapper = new LambdaQueryWrapper<>();
        for (Long id : ids) {
            asAttributeGroupService.remove(queryWrapper.eq(AsAttributeGroup::getGroupId,id));
        }
        return attributeGroupMapper.deleteAttributeGroupByIds(ids);
    }

    /**
     * 删除属性组信息
     *
     * @param id 属性组主键
     * @return 结果
     */
    @Override
    public int deleteAttributeGroupById(Long id) {
        return attributeGroupMapper.deleteAttributeGroupById(id);
    }
}
