package com.muyu.product.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.muyu.product.mapper.AttributeMapper;
import com.muyu.product.domain.Attribute;
import com.muyu.product.service.IAttributeService;

/**
 * 属性Service业务层处理
 *
 * @author saisai
 * @date 2024-02-29
 */
@Service
public class AttributeServiceImpl extends ServiceImpl<AttributeMapper,Attribute> implements IAttributeService
{
    @Autowired
    private AttributeMapper attributeMapper;

    /**
     * 查询属性
     *
     * @param id 属性主键
     * @return 属性
     */
    @Override
    public Attribute selectAttributeById(Long id)
    {
        return attributeMapper.selectAttributeById(id);
    }

    /**
     * 查询属性列表
     *
     * @param attribute 属性
     * @return 属性
     */
    @Override
    public List<Attribute> selectAttributeList(Attribute attribute)
    {
        return attributeMapper.selectAttributeList(attribute);
    }

    /**
     * 新增属性
     *
     * @param attribute 属性
     * @return 结果
     */
    @Override
    public int insertAttribute(Attribute attribute)
    {
        attribute.setCreateTime(DateUtils.getNowDate());
        return attributeMapper.insertAttribute(attribute);
    }

    /**
     * 修改属性
     *
     * @param attribute 属性
     * @return 结果
     */
    @Override
    public int updateAttribute(Attribute attribute)
    {
        attribute.setUpdateTime(DateUtils.getNowDate());
        return attributeMapper.updateAttribute(attribute);
    }

    /**
     * 批量删除属性
     *
     * @param ids 需要删除的属性主键
     * @return 结果
     */
    @Override
    public int deleteAttributeByIds(Long[] ids)
    {
        return attributeMapper.deleteAttributeByIds(ids);
    }

    /**
     * 删除属性信息
     *
     * @param id 属性主键
     * @return 结果
     */
    @Override
    public int deleteAttributeById(Long id)
    {
        return attributeMapper.deleteAttributeById(id);
    }
}
